@@ -42,6 +42,22 @@ def get_requirement(content):
         )
 
 
+def get_requirements(contents):
+    """Return the corresponding requirement instance from *content*.
+
+    :param contents: List of strings representing requirements, with or without
+        version specifier or variant (e.g. "maya", "nuke >= 10, < 11",
+        "ldpk-nuke[10.0]").
+
+    :return: List of :class:`packaging.requirements.Requirement` instances.
+
+    :raise: :exc:`wiz.exception.InvalidRequirement` if the requirement is
+        incorrect.
+
+    """
+    return [get_requirement(content) for content in contents]
+
+
 def get_version(content):
     """Return the corresponding version instance from *content*.
 
@@ -74,6 +90,9 @@ def is_overlapping(requirement1, requirement2):
         >>> is_overlapping(Requirement("foo >= 10"), Requirement("foo < 8"))
         False
 
+        >>> is_overlapping(Requirement("foo[V2]"), Requirement("foo[V1]"))
+        False
+
     :param requirement1: Instance of
         :class:`packaging.requirements.Requirement`.
 
@@ -82,16 +101,18 @@ def is_overlapping(requirement1, requirement2):
 
     :return: Boolean value.
 
-    :raise: :exc:`wiz.exception.GraphResolutionError` if requirements cannot
-        be compared.
+    :raise: :exc:`ValueError` if requirements cannot be compared.
 
     """
     if requirement1.name != requirement2.name:
-        raise wiz.exception.GraphResolutionError(
+        raise ValueError(
             "Impossible to compare requirements with different names "
             "['{}' and '{}'].".format(requirement1.name, requirement2.name)
         )
 
+    if requirement1.extras != requirement2.extras:
+        return False
+
     r1 = extract_version_ranges(requirement1)
     r2 = extract_version_ranges(requirement2)
     return (
@@ -638,6 +659,32 @@ def sanitize_requirement(requirement, package):
     return _requirement
 
 
+def compute_namespace_counter(requirements, definition_mapping):
+    """Compute namespace frequency counter from *requirements*.
+
+    :param requirements: List of :class:`packaging.requirements.Requirement`
+        instances.
+
+    :param definition_mapping: Mapping regrouping all available definitions
+        associated with their unique identifier.
+
+    :return: Instance of :class:`collections.Counter`.
+
+    """
+    mapping = definition_mapping.get("__namespace__", {})
+
+    namespaces = []
+
+    for requirement in requirements:
+        namespace, _ = wiz.utility.extract_namespace(requirement)
+        if namespace is not None:
+            namespaces.append(namespace)
+        else:
+            namespaces += mapping.get(requirement.name, [])
+
+    return collections.Counter(namespaces)
+
+
 def match(requirement, package):
     """Return whether *requirement* is compatible with *package*.
 
