@@ -3,7 +3,6 @@
 import os
 
 import pytest
-
 import wiz.config
 from wiz.utility import Requirement
 
@@ -1776,7 +1775,7 @@ def test_scenario_22(benchmark):
 def test_scenario_23(benchmark):
     """Compute packages for the following graph.
 
-    When a definition is found, its namespace is used to give hint when looking
+    Initial namespace counter can be used to give hint when looking
     for default namespace belonging to the other definitions.
 
     Root
@@ -1844,11 +1843,18 @@ def test_scenario_23(benchmark):
 
     def _resolve():
         """Resolve context."""
-        resolver = wiz.graph.Resolver(definition_mapping)
-        resolver.compute_packages([
+        requirements = [
             Requirement("A"), Requirement("B"), Requirement("C"),
             Requirement("D")
-        ])
+        ]
+        namespace_counter = wiz.utility.compute_namespace_counter(
+            requirements, definition_mapping
+        )
+
+        resolver = wiz.graph.Resolver(definition_mapping)
+        resolver.compute_packages(
+            requirements, namespace_counter=namespace_counter
+        )
 
     benchmark(_resolve)
 
@@ -1898,7 +1904,7 @@ def test_scenario_25(benchmark):
 
     When a definition exists with and without a namespace, other definitions
     using the same namespace within the request will lead to the selection of
-    the one with the namespace.
+    the one with the namespace if an initial counter is being used.
 
     Root
      |
@@ -1938,8 +1944,15 @@ def test_scenario_25(benchmark):
 
     def _resolve():
         """Resolve context."""
+        requirements = [Requirement("A"), Requirement("B")]
+        namespace_counter = wiz.utility.compute_namespace_counter(
+            requirements, definition_mapping
+        )
+
         resolver = wiz.graph.Resolver(definition_mapping)
-        resolver.compute_packages([Requirement("A"), Requirement("B")])
+        resolver.compute_packages(
+            requirements, namespace_counter=namespace_counter
+        )
 
     benchmark(_resolve)
 
@@ -2946,3 +2959,240 @@ def test_scenario_39(benchmark):
         ])
 
     benchmark(_resolve)
+
+
+def test_scenario_40(benchmark):
+    """Compute packages for the following graph.
+
+    Like scenario 34, a conflict appear when relinking parents as two
+    requirements are explicitly requesting conflicting variants: "A[V2]" and
+    "A[V3]". But this time, the graph contains a version conflict which will
+    be resolved by removing "A[V2]", hence making this conflict irrelevant.
+
+    Root
+     |
+     |--(A[V3]): A[V3]==1.0.0
+     |   |
+     |   `--(B >=3, <4): B==3.0.0
+     |
+     |--(C >=1): C==2.0.0
+     |   |
+     |   `--(A[V2]): A[V2]==1.0.0
+     |       |
+     |       `--(B >=2, <3): B==2.0.0
+     |
+     `--(E): E
+         |
+         `--(C >=1, <2): C==1.5.0
+
+    Expected: E, C==1.5.0, B==3.0.0, A[V3]==1.0.0
+
+    """
+    definition_mapping = {
+        "A": {
+            "1.0.0": wiz.definition.Definition({
+                "identifier": "A",
+                "version": "1.0.0",
+                "variants": [
+                    {
+                        "identifier": "V3",
+                        "requirements": ["B >=3, <4"]
+                    },
+                    {
+                        "identifier": "V2",
+                        "requirements": ["B >=2, <3"]
+                    }
+                ]
+            })
+        },
+        "B": {
+            "3.0.0": wiz.definition.Definition({
+                "identifier": "B",
+                "version": "3.0.0"
+            }),
+            "2.0.0": wiz.definition.Definition({
+                "identifier": "B",
+                "version": "2.0.0"
+            }),
+        },
+        "C": {
+            "2.0.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "2.0.0",
+                "requirements": ["A[V2]"]
+            }),
+            "1.5.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "1.5.0"
+            }),
+        },
+        "E": {
+            "-": wiz.definition.Definition({
+                "identifier": "E",
+                "requirements": ["C >=1, <2"]
+            }),
+        }
+    }
+
+    def _resolve():
+        """Resolve context."""
+        resolver = wiz.graph.Resolver(definition_mapping)
+        resolver.compute_packages([
+            Requirement("A[V3]"), Requirement("C >=1"), Requirement("E"),
+        ])
+
+    benchmark(_resolve)
+
+
+def test_scenario_41(benchmark):
+    """Compute packages for the following graph.
+
+    Like scenario 34, a conflict appear when relinking parents as two
+    requirements are explicitly requesting conflicting variants: "A[V2]" and
+    "A[V3]". But this time, the resolver can downgrade versions of conflicting
+    nodes to find a solution.
+
+    Root
+     |
+     |--(A[V3]): A[V3]==1.0.0
+     |   |
+     |   `--(B >=3, <4): B==3.0.0
+     |
+     `--(C): C==1.0.0
+         |
+         `--(A[V2]): A[V2]==1.0.0
+             |
+             `--(B >=2, <3): B==2.0.0
+
+    Expected: C==0.5.0, B==3.0.0, A[V3]==1.0.0
+
+    """
+    definition_mapping = {
+        "A": {
+            "1.0.0": wiz.definition.Definition({
+                "identifier": "A",
+                "version": "1.0.0",
+                "variants": [
+                    {
+                        "identifier": "V3",
+                        "requirements": ["B >=3, <4"]
+                    },
+                    {
+                        "identifier": "V2",
+                        "requirements": ["B >=2, <3"]
+                    }
+                ]
+            })
+        },
+        "B": {
+            "3.0.0": wiz.definition.Definition({
+                "identifier": "B",
+                "version": "3.0.0"
+            }),
+            "2.0.0": wiz.definition.Definition({
+                "identifier": "B",
+                "version": "2.0.0"
+            }),
+        },
+        "C": {
+            "1.0.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "1.0.0",
+                "requirements": ["A[V2]"]
+            }),
+            "0.5.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "0.5.0",
+            })
+        }
+    }
+
+    def _resolve():
+        """Resolve context."""
+        resolver = wiz.graph.Resolver(definition_mapping)
+        resolver.compute_packages([
+            Requirement("A[V3]"), Requirement("C")
+        ])
+
+    benchmark(_resolve)
+
+
+def test_scenario_42(benchmark):
+    """Fail to compute packages for the following graph.
+
+    Root
+     |
+     |--(A): A[V1]
+     |   |
+     |   `--(C>1): C==1.5.0
+     |
+     |--(A): A[V2]
+     |   |
+     |   `--(C>1): C==1.5.0
+     |
+     |--(B): B[V1]
+     |   |
+     |   `--(C<1): C==0.5.0
+     |
+     `--(B): B[V2]
+         |
+         `--(C<1): C==0.5.0
+
+    Expected: Unable to compute due to requirement compatibility between
+    'C <1' and 'C >1'.
+
+    """
+    definition_mapping = {
+        "A": {
+            "-": wiz.definition.Definition({
+                "identifier": "A",
+                "variants": [
+                    {
+                        "identifier": "V2",
+                        "requirements": ["C>1"]
+                    },
+                    {
+                        "identifier": "V1",
+                        "requirements": ["C>1"]
+                    },
+                ]
+            }),
+        },
+        "B": {
+            "-": wiz.definition.Definition({
+                "identifier": "B",
+                "variants": [
+                    {
+                        "identifier": "V2",
+                        "requirements": ["C<1"]
+                    },
+                    {
+                        "identifier": "V1",
+                        "requirements": ["C<1"]
+                    },
+                ]
+            }),
+        },
+        "C": {
+            "1.5.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "1.5.0"
+            }),
+            "0.5.0": wiz.definition.Definition({
+                "identifier": "C",
+                "version": "0.5.0"
+            }),
+        }
+    }
+
+    def _resolve():
+        """Resolve context."""
+        try:
+            resolver = wiz.graph.Resolver(definition_mapping)
+            resolver.compute_packages([
+                Requirement("A"), Requirement("B")
+            ])
+        except wiz.exception.GraphResolutionError:
+            pass
+
+    benchmark(_resolve)
